@@ -1,7 +1,7 @@
 #'@title Get OTB modules 
 #'@name parseOTBAlgorithms
 #'@description retrieve the OTB module folder content and parses the module names
-#'@param gili optional gis linkage as done by `linkOTB()``
+#'@param gili optional list of avalailable `OTB` binaries if not provided `linkOTB()` is called
 #'@export parseOTBAlgorithms
 #'
 #'@examples
@@ -35,9 +35,9 @@ parseOTBAlgorithms<- function(gili=NULL) {
 
 #'@title Get OTB function argument list
 #'@name parseOTBFunction
-#'@description retrieve the choosen function and parses all arguments with the defaults
-#'@param algo number or name of the algorithm as provided by `getOTBAlgorithm`
-#'@param gili optional gis linkage as done by `linkOTB()`
+#'@description retrieve the choosen function and returns a full argument list with the default settings
+#'@param algo either the number or the plain name of the `OTB` algorithm that is wanted. Note the correct (of current/choosen version) information is probided by `parseOTBAlgorithms()`
+#'@param gili optional list of avalailable `OTB` binaries if not provided `linkOTB()` is called
 #'@export parseOTBFunction
 #'
 #'@examples
@@ -64,7 +64,7 @@ parseOTBFunction <- function(algo=NULL,gili=NULL) {
     otb<-link2GI::linkOTB()
     path_OTB<- otb$pathOTB
   } else path_OTB<- gili$pathOTB
-  
+  otb<-gili
   ocmd<-tmp<-list()
   otbcmd <- list()
   otbhelp <- list()
@@ -72,15 +72,15 @@ parseOTBFunction <- function(algo=NULL,gili=NULL) {
   otbtype <- list()
   
   
-  if (algo != ""){
+  if (algo != "" & otb$exist){
     system("rm otb_module_dump.txt",intern = FALSE,ignore.stderr = TRUE)
     ifelse(Sys.info()["sysname"]=="Windows",
-           system(paste0(path_OTB,"otbcli_",paste0(algo," -help >>" ,tempdir(),"otb_module_dump.txt 2>&1"))), 
-           system2(paste0(path_OTB,"otbcli"),paste0(algo," -help >>" ,tempdir(),"otb_module_dump.txt 2>&1"))
-    )
+           system(paste0(file.path(R.utils::getAbsolutePath(path_OTB),paste0("otbcli_",algo,".bat"))," -help >> " ,file.path(R.utils::getAbsolutePath(tempdir()),paste0("otb_module_dump.txt 2>&1")))), 
+           system(paste0(file.path(R.utils::getAbsolutePath(path_OTB),paste0("otbcli_",algo))," -help >> " ,file.path(R.utils::getAbsolutePath(tempdir()),paste0("otb_module_dump.txt 2>&1"))))
+           )
     
-    txt<-readLines(paste0(tempdir(),"otb_module_dump.txt"))
-    file.remove(paste0(tempdir(),"otb_module_dump.txt"))
+    txt<-readLines(file.path(tempdir(),"otb_module_dump.txt"))
+    file.remove(file.path(tempdir(),"otb_module_dump.txt"))
     # Pull out the appropriate line
     args <- txt[grep("-", txt)]
     # obviously the format has changed. TODO
@@ -153,14 +153,14 @@ parseOTBFunction <- function(algo=NULL,gili=NULL) {
   for (arg in names(t)){
     if (arg =="input")  arg<-"in"
     if (arg != "progress")  {
-  system(paste0(path_OTB,"otbcli_",paste0(algo," -help ",arg ,paste0(" >> ",tempdir(),ocmd[[1]],"-",arg,".txt 2>&1"))))
-  helpList[[arg]]<-readLines(paste0(tempdir(),ocmd[[1]],"-",arg,".txt"))
-  file.remove(paste0(ocmd[[1]],"-",arg,".txt"))
-  drop <-grep(x = helpList[[arg]],pattern =  "\\w*no version information available\\w*")
-  drop<-append(drop,grep(x = helpList[[arg]],pattern =  '^$'))
-  helpList[[arg]]<-helpList[[arg]][-drop]
-  }
-  else if  (arg=="progress") helpList[["progress"]]<- "Report progress: It must be 0, 1, false or true"
+      system(paste0(path_OTB,"otbcli_",paste0(algo," -help ",arg ,paste0(" >> ",file.path(tempdir(),ocmd[[1]]),"-",arg,".txt 2>&1"))))
+      helpList[[arg]]<-readLines(paste0(file.path(tempdir(),ocmd[[1]]),"-",arg,".txt"))
+      #file.remove(paste0(file.path(tempdir(),ocmd[[1]]),"-",arg,".txt"),showWarnings = TRUE)
+      drop <-grep(x = helpList[[arg]],pattern =  "\\w*no version information available\\w*")
+      drop<-append(drop,grep(x = helpList[[arg]],pattern =  '^$'))
+      helpList[[arg]]<-helpList[[arg]][-drop]
+    }
+    else if  (arg=="progress") helpList[["progress"]]<- "Report progress: It must be 0, 1, false or true"
   }
   ocmd$help<-helpList
   return(ocmd)
@@ -180,7 +180,7 @@ parseOTBFunction <- function(algo=NULL,gili=NULL) {
 #' require(listviewer)
 #' 
 #' ## link to OTB
-#' otblink<-link2GI::linkOTB()
+#' otbLink<-link2GI::linkOTB()
 #' 
 #' if (otblink$exist) {
 #'  projRootDir<-tempdir()
@@ -195,7 +195,7 @@ parseOTBFunction <- function(algo=NULL,gili=NULL) {
 #' algoKeyword<- "LocalStatisticExtraction"
 #' 
 #' ## extract the command list for the choosen algorithm 
-#' cmd<-parseOTBFunction(algo = algoKeyword, gili = otblink)
+#' cmd<-parseOTBFunction(algo = algoKeyword, gili = otbLink)
 #' 
 #' ## get help using the convenient listviewer
 #' listviewer::jsonedit(cmd$help)
@@ -206,7 +206,7 @@ parseOTBFunction <- function(algo=NULL,gili=NULL) {
 #' cmd$radius <- 7
 #' 
 #' ## run algorithm
-#' retStack<-runOTB(cmd,gili = otblink)
+#' retStack<-runOTB(cmd,gili = otbLink)
 #' 
 #' ## plot raster
 #' raster::plot(retStack)
